"use client"

import { User } from "@prisma/client"
import { useRouter } from "next/navigation"
import { startTransition } from "react"
import { Button } from "./ui/button"

export default function AddGameToFinishedList(props: { gameId: string, user: User }) {

    const router = useRouter()
    const gameId = parseFloat(props.gameId)
    const user = props.user

    let formData: {
        id: String
        gameId: Number
        add: boolean
        planningGameList: number[] | undefined
        playingGameList: number[] | undefined
        finishedGameList: number[] | undefined
    } = {
        id: "",
        gameId: -1,
        add: true,
        planningGameList: undefined,
        playingGameList: undefined,
        finishedGameList: undefined
    }

    async function removeGame(e: any) {
        e.preventDefault()

        formData.id = user.id
        formData.finishedGameList = props.user.finishedGameList.filter((id) => id !== gameId)
        const response = await fetch('/api/users/gamelists', {
            method: 'PUT',
            body: JSON.stringify(formData)
        })

        startTransition(() => {
            // Refresh the current route and fetch new data from the server without
            // losing client-side browser or React state.
            router.refresh()
        })
        return await response.json()
    }

    async function addGame(e: any) {
        e.preventDefault()

        formData.id = user.id
        props.user.finishedGameList.push(gameId)
        formData.finishedGameList = props.user.finishedGameList
        const response = await fetch('/api/users/gamelists', {
            method: 'PUT',
            body: JSON.stringify(formData)
        })

        startTransition(() => {
            // Refresh the current route and fetch new data from the server without
            // losing client-side browser or React state.
            router.refresh()
        })
        return await response.json()
    }


    let button = <></>
    try {
        if (!props.user.finishedGameList.includes(parseFloat(props.gameId))) {
            button = (
                <form onSubmit={addGame}>
                    <Button type="submit" size="lg" variant="ghost" className="w-full justify-start">
                        Set as Finished
                    </Button>
                </form>
            )
        } else {
            button = (
                <form onSubmit={removeGame}>
                    <Button type="submit" size="lg" variant="ghost" className="w-full justify-start text-destructive">
                        Unset Finished
                    </Button>
                </form>
            )
        }
    } catch (error) {
        // throw new Error("Failed to check finished-playing-List");
    }

    return (
        button
    )
}